@@ -113,7 +113,7 @@ def iq_get_data(iq,symbol,symbols,timeframe):
     timeframe = timeframe_to_sec(timeframe)
     final_data = pd.DataFrame()
     for active in actives:
-        current = iq_get_all_candles(iq,symbol,timeframe,time.time())
+        current = iq_get_all_candles(iq,active,timeframe,time.time())
         main = pd.DataFrame()
         useful_frame = pd.DataFrame()
         for candle in current:
@@ -122,13 +122,32 @@ def iq_get_data(iq,symbol,symbols,timeframe):
             main = main.append(useful_frame)
             main.drop_duplicates()
         if active == symbol:
-            final_data = main.drop(columns = {'to','from'})
+            final_data = main.drop(columns = {'to'})
         else:
             main = main.drop(columns = {'from','to','open','min','max'})
             main.columns = [f'close_{active}',f'volume_{active}']
             final_data = final_data.join(main)
     final_data = final_data.loc[~final_data.index.duplicated(keep = 'first')]
-    return final_data
+    return final_data.rename(columns = {'from':'date','min':'low', 'max':'high'})
+
+
+
+
+def iq_predict_data(iq,symbol,symbols,timeframe):
+    actives = symbols
+    main = pd.DataFrame()
+    current = pd.DataFrame()
+    for active in actives:
+        if active == symbol:
+            main = iq_get_fastdata(iq,active,timeframe).drop(columns = {'to'})
+        else:
+            current = iq_get_fastdata(iq,active,timeframe)
+            current = current.drop(columns = {'from','to','open','min','max'})
+            current.columns = [f'close_{active}',f'volume_{active}']
+            main = main.join(current)
+
+    return main.rename(columns = {'from':'date','min':'low', 'max':'high'})
+
     
 def iq_get_fastdata(iq,symbol,timeframe): 
     iq_login(iq = iq, checkConnection = True)
